aboutsummaryrefslogtreecommitdiffstats
path: root/conkeror
diff options
context:
space:
mode:
authorGravatar Tom Willemsen2012-12-29 16:54:16 +0100
committerGravatar Tom Willemsen2012-12-29 16:54:16 +0100
commitb46793938598358a9ab5249bd97e8999d5ac67e6 (patch)
tree3461b18599341fd3be19b0c094d6a62775478b88 /conkeror
parentf379783d28e73b4613852fca58e0af3f8ea6ab87 (diff)
downloadmarkam-b46793938598358a9ab5249bd97e8999d5ac67e6.tar.gz
markam-b46793938598358a9ab5249bd97e8999d5ac67e6.zip
Rename linkwave to markam
Diffstat (limited to 'conkeror')
-rw-r--r--conkeror/markam.js (renamed from conkeror/linkwave.js)46
1 files changed, 23 insertions, 23 deletions
diff --git a/conkeror/linkwave.js b/conkeror/markam.js
index 75e3735..2151b17 100644
--- a/conkeror/linkwave.js
+++ b/conkeror/markam.js
@@ -1,4 +1,4 @@
-/* linkwave -- Store/retrieve/manage bookmarks
+/* markam -- Store/retrieve/manage bookmarks
Copyright (C) 2012 Tom Willemsen <tom at ryuslash dot org>
This program is free software: you can redistribute it and/or modify
@@ -17,16 +17,16 @@
/// Commentary:
// A wrapper script that should allow conkeror to interface with
// linkwave. Does not yet allow searching through collected
// bookmarks, only adding new ones.
/// Code:
-define_variable("linkwave_program", "linkwave",
- "The location of the linkwave executable.");
+define_variable("markam_program", "markam",
+ "The location of the markam executable.");
-function linkwave_add_url(I, url, title)
-{ // Add URL to linkwave, ask for a title (provide TITLE as a
+function markam_add_url(I, url, title)
+{ // Add URL to markam, ask for a title (provide TITLE as a
// default), description and any number of tags.
let url_string = load_spec_uri_string(load_spec(url));
let title = yield I.minibuffer.read($prompt="name (required): ",
@@ -37,7 +37,7 @@ function linkwave_add_url(I, url, title)
let tags = yield I.minibuffer.read(
$prompt="tags (comma delimited): "
);
- let command = linkwave_program + ' "' + url_string + '" "' + title
+ let command = markam_program + ' "' + url_string + '" "' + title
+ '" "' + description + '" \''
+ tags.split(',').map(function (str)
{ return str.trim(); }).join("' '")
@@ -45,33 +45,33 @@ function linkwave_add_url(I, url, title)
yield shell_command(command);
}
-function linkwave_add(I) {
+function markam_add(I) {
check_buffer(I.buffer, content_buffer);
- let result = yield linkwave_add_url(I, I.buffer.top_frame,
+ let result = yield markam_add_url(I, I.buffer.top_frame,
I.buffer.title);
if (!result)
- I.window.minibuffer.message('Added to linkwave');
+ I.window.minibuffer.message('Added to markam');
else
- I.window.minibuffer.message('Couldn\'t add to linkwave');
+ I.window.minibuffer.message('Couldn\'t add to markam');
}
-interactive("linkwave-add",
- "Bookmark the current page in linkwave",
- linkwave_add);
+interactive("markam-add",
+ "Bookmark the current page in markam",
+ markam_add);
-function linkwave_add_link(I) {
+function markam_add_link(I) {
check_buffer(I.buffer, content_buffer);
bo = yield read_browser_object(I);
- let result = yield linkwave_add_url(I, encodeURIComponent(bo),
+ let result = yield markam_add_url(I, encodeURIComponent(bo),
bo.textContent);
if (!result)
- I.window.minibuffer.message('Added to linkwave');
+ I.window.minibuffer.message('Added to markam');
else
- I.window.minibuffer.message('Couldn\'t add to linkwave');
+ I.window.minibuffer.message('Couldn\'t add to markam');
}
-interactive("linkwave-add-link",
- "Select and bookmark a link in linkwave",
- linkwave_add_link);
+interactive("markam-add-link",
+ "Select and bookmark a link in markam",
+ markam_add_link);
-provide("linkwave");
+provide("markam");
@@ -17,16 +17,16 @@
/// Commentary:
// A wrapper script that should allow conkeror to interface with
-// linkwave. Does not yet allow searching through collected
-// bookmarks, only adding new ones.
+// markam. Does not yet allow searching through collected bookmarks,
+// only adding new ones.
/// Code: